@@ -34,7 +34,7 @@ class VulnerabilityTest(ABC):
         Call the appropriate scan methods
 
         :return: Result of a scan
-        :rtype: tuple
+        :rtype: tuple[bool, str]
         """
         log.info(f"Testing for {self.name}")
         usable_protocols = [
@@ -54,9 +54,9 @@ class VulnerabilityTest(ABC):
         """
         Test the webserver for a vulnerability on a protocol versions
 
-        :param: list usable_protocols
+        :param: list[str] usable_protocols
         :return: Whether a test was positive
-        :rtype: bool or tuple
+        :rtype: bool or tuple[bool, str]
         """
         protocol = self.protocol
         if protocol not in self.valid_protocols:
@@ -71,9 +71,9 @@ class VulnerabilityTest(ABC):
         """
         Test the webserver for a vulnerability on all valid protocol versions
 
-        :param: list usable_protocols
+        :param: list[str] usable_protocols
         :return: Whether any test was positive
-        :rtype: bool or tuple
+        :rtype: bool or tuple[bool, str]
         """
         result_tuple: tuple
         self.run_once()
@@ -100,9 +100,9 @@ class VulnerabilityTest(ABC):
         Implemented test functions can either return just a bool value
         or a tuple containing a comment together with the test result
 
-        :param list results: Test results
+        :param list[bool or tuple[bool, str]] results: Test results
         :return: One tuple or one bool value
-        :rtype: bool or tuple
+        :rtype: bool or tuple[bool, str]
         """
         result_tuples = list(filter(lambda r: type(r) == tuple, results))
         if len(result_tuples) == 0:
@@ -126,10 +126,10 @@ class VulnerabilityTest(ABC):
         """
         Run tests in parallel
 
-        :param list protocol_binary_versions:
         :param function: Functions to be run
+        :param list[str] protocol_binary_versions:
         :return: Results of the scans
-        :rtype: list
+        :rtype: list[bool or tuple[bool, str]]
         """
         # List that all the threads live
         futures = []
@@ -154,7 +154,7 @@ class VulnerabilityTest(ABC):
 
         :param int version: SSL/TLS version to test on
         :return: Whether the test passed or not
-        :rtype: bool or tuple
+        :rtype: bool or tuple[bool, str]
         """
         pass
 
